@@ -1102,6 +1102,17 @@ class Query {
     return *this;
   }
 
+  /**
+   * Get the config
+   * @return Config
+   */
+  Config config() const {
+    tiledb_config_t* config;
+    tiledb_query_get_config(ctx_.get().ptr().get(), query_.get(), &config);
+
+    return Config(&config);
+  }
+
   /**
    * Set the coordinate buffer.
    *
